{#- OZI 0.1
# ozi/templates/project.name/__init__.py.j2
# Part of the OZI Project, under the Apache License v2.0 with LLVM Exceptions.
# See LICENSE.txt for license information.
# SPDX-License-Identifier: Apache-2.0 WITH LLVM-exception
-#}
"""{{ project.name }} module"""
{%- for line in project.copyright_head.split('\n') %}
{{ '# ' ~ line }}
{%- endfor %}
{%- if user_template %}
{% extends user_template %}
{%- endif %}

